#!/usr/bin/env python
# Sean Feole 2012, LDAP Query
# Rev 1.0

import sys
import StringIO
import Image
import ldap
import re
import pygtk
pygtk.require('2.0')
import gtk
import argparse


class GtkLdap:

    def delete(self, widget, event=None):
        gtk.main_quit()
        return False

    def configfile(self, configlocation):

        print ("Using Config File at: %s" % configlocation)

        myfile = open(configlocation, "r").readlines()
        scaninit = myfile[5]
        configcheck = scaninit.find("Insert Host Address")

        if configcheck is 18:
            print("Please Configure the config.txt file")
            sys.exit()
        else:
            self.init = scaninit.split("=")[1].strip().strip("\"")

            scanbind = myfile[6]
            self.bind = scanbind.split("\"")[1]

            scanpasswd = myfile[7]
            self.passwd = scanpasswd.split("=")[1].strip().strip("\"")

            scanbasedn = myfile[8]
            self.basedn = scanbasedn.split("\"")[1]

    def searchstring(self, name):
        self.name = name

    def displayme(self):
        print ("Searching For: %s" % self.name)

    def ldap(self):

        init = "%s" % self.init
        bind = "%s" % self.bind
        passwd = "%s" % self.passwd
        basedn = "%s" % self.basedn
        searchstring = "%s" % self.name

        window = gtk.Window(gtk.WINDOW_TOPLEVEL)
        window.connect("delete_event", self.delete)
        window.set_border_width(10)

        table = gtk.Table(3, 6, False)
        window.add(table)

        notebook = gtk.Notebook()
        notebook.set_tab_pos(gtk.POS_LEFT)
        notebook.set_scrollable(True)
        notebook.set_current_page(1)
        table.attach(notebook, 0, 6, 0, 1)
        notebook.show()
        self.show_tabs = True
        self.show_border = True
        entryFound = False

        try:
            l = ldap.initialize(init)
            l.protocol_version = ldap.VERSION3
            l.bind_s(bind, passwd)
        except ldap.LDAPError:
            print ("Error Binding to Ldap Server")
            sys.exit()

        baseDN = (basedn)
        searchScope = ldap.SCOPE_SUBTREE
        retrieveAttributes = None
        searchFilter = "cn=*%s*" % searchstring

        ldap_result_id = l.search(baseDN, searchScope, searchFilter,
         retrieveAttributes)
        result_set = []
        print ("Processing")
        while True:
            result_type, result_data = l.result(ldap_result_id, 0)
            if not result_data:
                print ("No Additional Entries to Parse")
                break
            else:
                if result_type == ldap.RES_SEARCH_ENTRY:
                    count = 1
                    for number in result_set:
                        count += 1
                    result_set.append(result_data)
                    for i in range(len(result_set)):
                        for entry in result_set[i]:
                            #Find Each Entry, If the Entry does
                            #not exist then default "Not Found"

                            if 'cn' in entry[1]:
                                name = entry[1]['cn'][0]
                            else:
                                cn = "Not Found"
                            if 'title' in entry[1]:
                                title = entry[1]['title'][0]
                            else:
                                title = "Not Found"
                            if 'mail' in entry[1]:
                                email = entry[1]['mail'][0]
                            else:
                                email = "Not Found"
                            if 'telephoneNumber' in entry[1]:
                                telephone = entry[1]['telephoneNumber'][0]
                            else:
                                telephone = "Not Found"
                            if 'mobile' in entry[1]:
                                mobile = entry[1]['mobile'][0]
                            else:
                                mobile = "Not Found"
                            if 'ou' in entry[1]:
                                org = entry[1]['ou'][0]
                            else:
                                org = "Not Found"
                            if 'launchpadID' in entry[1]:
                                launchpad = entry[1]['launchpadID'][0]
                            else:
                                launchpad = "Not Found"
                            jpeg = entry[1]['jpegPhoto'][0]

                myinfo = "\nName: %s\nTitle: %s\nOrg: %s\nPhone: %s\
                    \nMobile: %s\nEmail: %s\nLaunchpad: %s\n"\
                    % (name, title, org, telephone, mobile, email,
                       launchpad)

                jpegnew = Image.open(StringIO.StringIO(jpeg))
                jpegnew.save("/tmp/image.jpg", "JPEG")

                image = gtk.Image()
                image.set_from_file("/tmp/image.jpg")
                image.show()

                bufferf = "%s" % (myinfo)
                bufferl = "%s" % (name)

                frame = gtk.Frame()
                frame.set_border_width(10)
                frame.set_size_request(500, 300)
                frame.show()

                bodywin = gtk.HBox(False, 0)
                bodywin.show()

                frame.add(bodywin)
                label = gtk.Label(bufferf)
                bodywin.pack_end(image, False, False, 0)
                bodywin.pack_end(label, True, True, 0)
                label.show()

                label = gtk.Label(bufferl)
                notebook.append_page(frame, label)
                entryFound = True

    #Create the Bottom Buttons
        button = gtk.Button("close")
        button.connect("clicked", self.delete)
        table.attach(button, 0, 1, 1, 2)
        button.show()

        button = gtk.Button("next page")
        button.connect("clicked", lambda w: notebook.next_page())
        table.attach(button, 1, 2, 1, 2)
        button.show()

        button = gtk.Button("prev page")
        button.connect("clicked", lambda w: notebook.prev_page())
        table.attach(button, 2, 3, 1, 2)
        button.show()

        table.show()
        window.show()
        return entryFound


def main():

    parser = argparse.ArgumentParser()
    parser.add_argument('-s', '--searchstring',
                        help="Name of the Individual to search", required=True)
    #parser.add_argument('-c', '--config',
    #                    help="Location of the config file", required=True)
    args = parser.parse_args()

    args.config = "/usr/local/etc/lquery/config.txt"
    ldap = GtkLdap()
    ldap.configfile('%s' % args.config)
    ldap.searchstring('%s' % args.searchstring)
    print(ldap.displayme())
    if ldap.ldap():
        gtk.main()
    return 0

if __name__ == "__main__":
    GtkLdap()
    main()
